@@ -3,7 +3,7 @@ from logging import basicConfig, getLogger
 from time import sleep
 from typing import Any, List, Union, Tuple, Sequence, Sized
 
-import numpy as np
+from numpy import array, NaN, nan, nan_to_num, ndarray
 from pandas import DataFrame, Series
 from ta.volatility import AverageTrueRange
 
@@ -35,10 +35,10 @@ GREEN: str = '#55ff00'
 BLUE: str = '#0015ff'
 CYAN: str = 'cyan'
 BUY: PREDICT_TYPE = 1
-SELL: PREDICT_TYPE = 0
-EXIT: PREDICT_TYPE = 2
+SELL: PREDICT_TYPE = -1
+EXIT: PREDICT_TYPE = 0
 
-__version__: str = "5.2.1"
+__version__: str = "5.5.0"
 __author__: str = 'Vlad Kochetov'
 __credits__: List[str] = ["Hemerson Tacon -- Stack overflow",
                           "hpaulj -- Stack overflow",
@@ -121,7 +121,7 @@ class SuperTrendIndicator(object):
         """
         m = self.close.size
         dir_, trend = [1] * m, [0] * m
-        long, short = [np.NaN] * m, [np.NaN] * m
+        long, short = [NaN] * m, [NaN] * m
         ATR = AverageTrueRange(high=self.high, low=self.low, close=self.close, window=self.length)
 
         hl2_ = (self.high + self.low) / 2
@@ -165,12 +165,12 @@ def convert(data: PREDICT_TYPE_LIST) -> CONVERTED_TYPE_LIST:
     e: int
     for e, i in enumerate(data[1:]):
         if i == data[e]:
-            ret[e + 1] = np.nan
+            ret[e + 1] = nan
     return ret
 
 
 def anti_convert(converted: CONVERTED_TYPE_LIST, _nan_num: float = 18699.9) -> PREDICT_TYPE_LIST:
-    converted = np.nan_to_num(converted, nan=_nan_num)
+    converted = nan_to_num(converted, nan=_nan_num)
     ret: List[Any] = [converted[0]]
     flag = converted[0]
     e: int
@@ -199,14 +199,14 @@ def convert_signal_str(predict: PREDICT_TYPE) -> str:
         return 'Exit'
 
 
-def get_exponential_growth(dataset: Sequence[float]) -> np.ndarray:
+def get_exponential_growth(dataset: Sequence[float]) -> ndarray:
     return_list: List[float] = []
     coef = profit_factor(dataset)
     curr = dataset[0]
     for i in range(len(dataset)):
         return_list.append(curr)
         curr *= coef
-    return np.array(return_list)
+    return array(return_list)
 
 
 def get_coef_sec(timeframe: str = '1d') -> Tuple[float, int]:
@@ -277,21 +277,20 @@ def get_coef_sec(timeframe: str = '1d') -> Tuple[float, int]:
 def wait_success(func):
     @wraps(func)
     def checker(*args, **kwargs):
-        if USE_WAIT_SUCCESS:
-            while True:
-                try:
-                    return func(*args, **kwargs)
-                except Exception as e:
-                    if not isinstance(e, KeyboardInterrupt):
-                        if WAIT_SUCCESS_PRINT:
-                            print(f'An error occurred: {e}, repeat request')
-                        logger.error(f'An error occurred: {e}', exc_info=True)
-                        sleep(WAIT_SUCCESS_SLEEP)
-                        continue
-                    else:
-                        raise e
-        else:
-            return func(*args, **kwargs)
+        while True:
+            try:
+                return func(*args, **kwargs)
+            except Exception as e:
+                if not USE_WAIT_SUCCESS:
+                    raise e
+                if not isinstance(e, KeyboardInterrupt):
+                    if WAIT_SUCCESS_PRINT:
+                        print(f'An error occurred: {e}, repeat request')
+                    logger.error(f'An error occurred: {e}', exc_info=True)
+                    sleep(WAIT_SUCCESS_SLEEP)
+                    continue
+                else:
+                    raise e
 
     return checker
 
@@ -308,9 +307,31 @@ def assert_logger(func):
     @wraps(func)
     def wrapper(*args, **kwargs):
         try:
-            func(*args, **kwargs)
+            return func(*args, **kwargs)
         except AssertionError as AE:
             logger.critical(AE)
             raise AE
 
     return wrapper
+
+
+def get_diff(price: float,
+             low: float,
+             high: float,
+             stop_loss: float,
+             take_profit: float,
+             signal: PREDICT_TYPE) -> float:
+    if signal == EXIT:
+        return 0.0
+
+    if signal == BUY and low <= stop_loss:
+        return stop_loss - price
+
+    elif signal == SELL and high >= stop_loss:
+        return stop_loss - price
+
+    elif signal == BUY and high >= take_profit:
+        return take_profit - price
+
+    elif signal == SELL and low <= take_profit:
+        return take_profit - price
